@@ -58,48 +58,57 @@ define('CGGM_NEWBALOON_TEMPLATE','cggm_baloon_template');
  *
  * @ignore
  */
+function cggm_set_var($params, &$smarty)
+{
+  $map = '';
+  $mod = cms_utils::get_module('CGGoogleMaps');
+  if( isset($params['map']) ) {
+    $map = $params['map'];
+    unset($params['map']);
+  }
+  else {
+    $map = $mod->GetPreference('default_map',0);
+  }
+
+  foreach( $params as $key => $value ) {
+    $mod->add_attr($map,$key,$value);
+  }
+}
+
 function cggm_add_category($params, &$smarty)
 {
   $map = '';
-  if( isset($params['map']) )
-    {
-      $map = $params['map'];
-    }
-  else
-   {
-      global $gCms;
-      $mod =& $gCms->modules['CGGoogleMaps']['object'];
-      $map = $mod->GetPreference('default_map',0);
-   }
+  if( isset($params['map']) ) {
+    $map = $params['map'];
+  }
+  else {
+    $mod = cms_utils::get_module('CGGoogleMaps');
+    $map = $mod->GetPreference('default_map',0);
+  }
 
-  if( !isset($params['name']) )
-    {
-      // name is required
-      return; 
-    }
+  if( !isset($params['name']) ) {
+    // name is required
+    return; 
+  }
   $name = $params['name'];
   
   $key = $name;
-  if( isset($params['key']) )
-    {
-      $key = trim($params['name']);
-    }
+  if( isset($params['key']) ) {
+    $key = trim($params['name']);
+  }
 
   $description = '';
-  if( isset($params['desc']) )
-    {
-      $description = $params['desc'];
-    }
-  if( isset($params['description']) )
-    {
-      $description = $params['description'];
-    }
+  if( isset($params['desc']) ) {
+    $description = $params['desc'];
+  }
+  if( isset($params['description']) ) {
+    $description = $params['description'];
+  }
   
   $icon = '';
-  if( isset($params['icon']) )
-    {
-      $icon = $params['icon'];
-    }
+  if( isset($params['icon']) ) {
+    $icon = $params['icon'];
+  }
 
   $mod = cge_utils::get_module('CGGoogleMaps');
   $obj = new cggm_category($name,$key);
@@ -116,17 +125,23 @@ function cggm_add_dynpoint($params, &$smarty)
 {
   $mod = cge_utils::get_module('CGGoogleMaps');
   if( !$mod ) return;
-  $map = '';
+
+  $keys = '';
   if( isset($params['map']) ) {
-    $map = $params['map'];
+    if( !is_numeric($params['map']) ) {
+      $mapobj = cggm_map_operations::load_by_name($params['map']);
+      if( $mapobj ) $keys = array($mapobj->id);
+    }
+    else {
+      $keys = array($params['map']);
+    }
   }
-  else {
-    $map = $mod->GetPreference('default_map',0);
+
+  if( isset($params['keys']) && $params['keys'] != '' ) {
+    $keys = explode(',',$params['keys']);
   }
-  
-  if( !is_numeric($map) ) {
-    $mapobj = cggm_map_operations::load_by_name($map);
-    $map = $mapobj->id;
+  else if( !is_array($keys) ) {
+    $keys = array($mod->GetPreference('default_map',0));
   }
 
   if( !isset($params['name']) ) {
@@ -183,16 +198,15 @@ function cggm_add_dynpoint($params, &$smarty)
     if( isset($params['tooltip']) && $params['tooltip'] != '' ) {
       $obj->set_tooltip($params['tooltip']);
     }
-    $mod->add_map_point($map,$obj);
+    foreach( $keys as $onekey ) {
+      $mod->add_map_point($onekey,$obj);
+    }
   }
   catch( Exception $e ) {
     echo '<!-- ERROR: problem adding map point '.$name.' -->'."\n";
   }
 }
 
-/*---------------------------------------------------------
- cggm_add_dynpoint()
- ---------------------------------------------------------*/
 function cggm_add_kml($params, &$smarty)
 {
   $mod = cge_utils::get_module('CGGoogleMaps');
@@ -227,122 +241,79 @@ class CGGoogleMaps extends CGExtensions
   var $_dynamic_points;
   var $_dyn_categories;
   var $_kml_files;
+  var $_dyn_attrs;
 
-  /*---------------------------------------------------------
-   CGGoogleMaps() -- Constructor
-   ---------------------------------------------------------*/
   function CGGoogleMaps()
   {
     parent::CMSModule();
     $this->_dynamic_points = null;
     $this->AddImageDir('icons');
 
-    global $gCms;
-    $smarty =& $gCms->GetSmarty();
+    $gCms = cmsms();
+    $smarty = $gCms->GetSmarty();
+    $smarty->register_function('cggm_set_var','cggm_set_var');
     $smarty->register_function('cggm_add_dynpoint','cggm_add_dynpoint');
     $smarty->register_function('cggm_add_kml','cggm_add_kml');
   }
 
-  /*---------------------------------------------------------
-   GetName()
-   ---------------------------------------------------------*/
   function GetName()
   {
     return 'CGGoogleMaps';
   }
 
-  /*---------------------------------------------------------
-   GetFriendlyName()
-   ---------------------------------------------------------*/
   function GetFriendlyName()
   {
     return $this->Lang('friendlyname');
   }
-
 	
-  /*---------------------------------------------------------
-   GetVersion()
-   ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '2.3.1';
+    return '2.4.2';
   }
 
-
-  /*---------------------------------------------------------
-   GetHelp()
-   ---------------------------------------------------------*/
   function GetHelp()
   {
     return file_get_contents(dirname(__FILE__).'/help.inc');
   }
 
-
-  /*---------------------------------------------------------
-   GetAuthor()
-   ---------------------------------------------------------*/
   function GetAuthor()
   {
     return 'calguy1000';
   }
 
-
-  /*---------------------------------------------------------
-   GetAuthorEmail()
-   ---------------------------------------------------------*/
   function GetAuthorEmail()
   {
     return 'calguy1000@hotmail.com';
   }
 
-
-  /*---------------------------------------------------------
-   GetChangeLog()
-   ---------------------------------------------------------*/
   function GetChangeLog()
   {
     return file_get_contents(dirname(__FILE__).'/changelog.inc');
   }
   
-  /*---------------------------------------------------------
-   IsPluginModule()
-   ---------------------------------------------------------*/
   function IsPluginModule()
   {
     return true;
   }
 
-
-  /*---------------------------------------------------------
-   HasAdmin()
-   ---------------------------------------------------------*/
   function HasAdmin()
   {
     return true;
   }
 
-
-  /*---------------------------------------------------------
-   GetAdminSection()
-   ---------------------------------------------------------*/
   function GetAdminSection()
   {
     return 'extensions';
   }
 
-
-  /*---------------------------------------------------------
-   GetAdminDescription()
-   ---------------------------------------------------------*/
   function GetAdminDescription()
   {
     return $this->Lang('moddescription');
   }
 
+  function LazyLoadAdmin() { return TRUE; }
+  function LazyLoadFrontend() { return FALSE; }
 
-  /*---------------------------------------------------------
-   GetHeaderHTML()
-   ---------------------------------------------------------*/
   function GetHeaderHTML()
   {
     $obj =& $this->GetModuleInstance('JQueryTools');
@@ -356,10 +327,6 @@ EOT;
       }
   }	
 
-
-  /*---------------------------------------------------------
-   VisibleToAdminUser()
-   ---------------------------------------------------------*/
   function VisibleToAdminUser()
   {
     return $this->CheckPermission('Manage Maps') ||
@@ -368,29 +335,17 @@ EOT;
       $this->CheckPermission('Modify Site Preferences');
   }
 
-
-  /*---------------------------------------------------------
-   GetDependencies()
-   ---------------------------------------------------------*/
   function GetDependencies()
   {
     return array('CGExtensions'=>'1.22.2',
 		 'CGSimpleSmarty'=>'1.4');
   }
 
-
-  /*---------------------------------------------------------
-   MinimumCMSVersion()
-   ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
     return "1.9.4.2";
   }
 	
-	
-  /*---------------------------------------------------------
-   SetParameters()
-   ---------------------------------------------------------*/
   function SetParameters()
   {
     $this->RegisterModulePlugin();
@@ -398,6 +353,9 @@ EOT;
 
     $this->CreateParameter('map','',$this->Lang('help_param_map'));
     $this->SetParameterType('map',CLEAN_STRING);
+
+    $this->CreateParameter('key','',$this->Lang('help_param_key'));
+    $this->SetParameterType('key',CLEAN_STRING);
     
     $this->CreateParameter('defer','0',$this->Lang('help_param_defer'));
     $this->SetParameterType('defer',CLEAN_INT);
@@ -411,56 +369,38 @@ EOT;
     $this->CreateParameter('zoom_encompass','',$this->Lang('help_param_zoomencompass'));
     $this->SetParameterType('zoom_encompass',CLEAN_INT);
 
+    $this->CreateParameter('width','',$this->Lang('help_param_width'));
+    $this->SetParameterType('width',CLEAN_INT);
+
+    $this->CreateParameter('height','',$this->Lang('help_param_height'));
+    $this->SetParameterType('height',CLEAN_INT);
+
     $this->SetParameterType('address',CLEAN_STRING);
   }
 
-
-  /*---------------------------------------------------------
-   InstallPostMessage()
-   ---------------------------------------------------------*/
   function InstallPostMessage()
   {
     return $this->Lang('postinstall');
   }
 
-
-  /*---------------------------------------------------------
-   UninstallPostMessage()
-   ---------------------------------------------------------*/
   function UninstallPostMessage()
   {
     return $this->Lang('postuninstall');
   }
 
-
-  /*---------------------------------------------------------
-   UninstallPreMessage()
-   ---------------------------------------------------------*/
   function UninstallPreMessage()
   {
     return $this->Lang('really_uninstall');
   }	
 
-
-  /*---------------------------------------------------------
-   AllowAutoInstall()
-   ---------------------------------------------------------*/
   function AllowAutoInstall() {
     return FALSE;
   }
 
-
-  /*---------------------------------------------------------
-   AllowAutoUpgrade()
-   ---------------------------------------------------------*/
   function AllowAutoUpgrade() {
     return FALSE;
   }
 
-
-  /*---------------------------------------------------------
-   GetCoordsFromAddress()
-   ---------------------------------------------------------*/
   function GetCoordsFromAddress($address)
   {
     $tmp = cggm_address_lookup::lookup($address);
@@ -474,7 +414,6 @@ EOT;
     return $tmp;
   }
 
-
   // getBoundingBox
   // hacked out by ben brown <ben@xoxco.com>
   // http://xoxco.com/clickable/php-getboundingbox
@@ -534,21 +473,20 @@ EOT;
     return array($lat1,$lat2,$lon1,$lon2);
   }
 
-function AddDynamicPoint($map,$name,$description,$address='',$lat='',$long='',$icon='',$tooltip = '',
-			 $sidebar_class = '',$sidebar_html = '')
+  function AddDynamicPoint($map,$name,$description,$address='',
+			   $lat='',$long='',$icon='',$tooltip = '',
+			   $sidebar_class = '',$sidebar_html = '')
   {
     if( empty($map) ) return FALSE;
     if( empty($name) ) return FALSE;
     if( empty($address) && (empty($lat) || empty($long)) ) return FALSE;
 
-    if( !is_array($this->_dynamic_points) )
-      {
-	$this->_dynamic_points = array();
-      }
-    if( !isset($this->_dynamic_points[$map]) )
-      {
-	$this->_dynamic_points[$map] = array();
-      }
+    if( !is_array($this->_dynamic_points) ) {
+      $this->_dynamic_points = array();
+    }
+    if( !isset($this->_dynamic_points[$map]) ) {
+      $this->_dynamic_points[$map] = array();
+    }
 
     // everything is good to go, build the point object.
     $obj = new cggm_marker($name,$address,$lat,$long,$icon);
@@ -556,35 +494,27 @@ function AddDynamicPoint($map,$name,$description,$address='',$lat='',$long='',$i
     $this->add_map_point($map,$obj);
   }
 
-
   public function add_map_point($map,cggm_marker& $obj)
   {
-    // todo, convert map name to a map id here.
-    $map = (int)$map;
-    if( !is_array($this->_dynamic_points) )
-      {
-	$this->_dynamic_points = array();
-      }
-    if( !isset($this->_dynamic_points[$map]) )
-      {
-	$this->_dynamic_points[$map] = array();
-      }
+    if( !is_array($this->_dynamic_points) ) {
+      $this->_dynamic_points = array();
+    }
+    if( !isset($this->_dynamic_points[$map]) ) {
+      $this->_dynamic_points[$map] = array();
+    }
 
     $this->_dynamic_points[$map][] = $obj;
   }
 
-
   public function add_map_category($map,cggm_category& $obj)
   {
     if( $map == '' ) return FALSE;
-    if( !is_array($this->_dyn_categories) )
-      {
-	$this->_dyn_categories = array();
-      }
-    if( !isset($this->_dyn_categories[$map]) )
-      {
-	$this->_dyn_categories[$map] = array();
-      }
+    if( !is_array($this->_dyn_categories) ) {
+      $this->_dyn_categories = array();
+    }
+    if( !isset($this->_dyn_categories[$map]) ) {
+      $this->_dyn_categories[$map] = array();
+    }
 
     $this->_dyn_categories[$map][] = $obj;
   }
@@ -595,12 +525,28 @@ function AddDynamicPoint($map,$name,$description,$address='',$lat='',$long='',$i
     if( !is_array($this->_kml_files) ) {
       $this->_kml_files = array();
     }
-    if( !isset($this->_kml_files[$map]) )
-      {
-	$this->_kml_files[$map] = array();
-      }
+    if( !isset($this->_kml_files[$map]) ) {
+      $this->_kml_files[$map] = array();
+    }
     $this->_kml_files[$map][] = $href;
   }
+
+  public function add_attr($map,$key,$value)
+  {
+    $map = (int)$map;
+    if( !is_array($this->_dyn_attrs) ) {
+      $this->_dyn_attrs = array();
+    }
+    if( !isset($this->_dyn_attrs[$map]) ) {
+      $this->_dyn_attrs[$map] = array();
+    }
+    if( $value !== '' ) {
+      $this->_dyn_attrs[$map][$key] = $value;
+    }
+    else {
+      unset($this->_dyn_attrs[$map][$key]);
+    }
+  }
 } // class
 
 ?>
