@@ -56,93 +56,6 @@ $lang['friendlyname'] = 'Calguys Google Maps ';
 $lang['from'] = 'Formulier';
 $lang['get_directions'] = 'Verkrijg bestemmingen';
 $lang['google_api_key'] = 'Google API sleutel';
-$lang['help'] = '<h3>What does this do</h3>
-  <p>This module provides a quick, convenient, yet flexible and extendable way to place google maps on a page providing a number of built in functions, and providing easy extendability for those familiar with Javascript and the Google Maps API&#039;;
-<h3>Features:</h3>
-<ul>
-  <li>Static map creation using a full admin interface for managing maps and markers within a map.</li>
-  <li>Flexible marker icon management.</li>
-  <li>The ability to categorize markers.  Markers can belong to more than one category.</li>
-  <li>Infowindow content can be specified using HTML</li>
-  <li>Streetview support</li>
-  <li>The ability to display a sidebar of all markers associated with a map.</li>
-  <li>The ability to display a category panel, and hide icons by unchecking a category checkbox.</li>
-  <li>Directions support (either by displaying the route in the map (and with directions in a seperate panel), or by opening a new window</li>
-  <li>Reads sensor information from GPS sensors on mobile devices.</li>
-  <li>The ability to group markers that are within a lat/long radius to a single marker with a special icon.</li>
-  <li>The ability to dynamically add markers given data from an outside point <em>(see {cggm_add_dynpoint})</em>
-  <li>Uses jquery for advanced DOM manipulation.</li>
-</ul>
-<h3>How Do I Use It?</h3>
-<ul>
-<li>Install the module via the normal methods</li>
-<li>Setup your users and groups with the appropriate permissions:
-  <ul>
-    <li>The &#039;Manage Maps&#039; Permission allows administrators to add/edit and delete maps</li>
-    <li>The &#039;Manage Map Locations&#039; permission allows administrators to add/edit/delete points within a map</li>
-  </ul>
-</li>
-<li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking.  Note that when resetting one of the map templates to defaults, you must still press the &amp;quot;Apply&amp;quot; or &amp;quot;Apply&amp;quot; buttons.</p>
-<li>Mark one of your maps as default, by clicking on the red &#039;X&#039; beside a particular map.  This is useful if you don&#039;t specify the &#039;map&#039; parameter on the tag.</li>
-<li>Create one or more points within the map, either by specifying a latitude and longitude, or with an address.</li>
-<li>Add the {CGGoogleMaps} tag inside the content block of a page, or inside a page template.  Then you&#039;re finished.</li>
-</ul>
-<br/>
-<h3>Adding Points to a Map Dynamically</h3>
-<p>You can use smarty to add points to a module dynamically.  You can use this functionality to build a frappr like map with multiple points that are controlled dynamically from another module (like CompanyDirectory or FrontEndUsers).</p>
-<h4>The {cggm_add_dynpoint} Smarty Plugin</h4>
-<p>This smarty plugin <em>(only available when CGGoogleMaps is installed)</em> allows adding a point dynamically to a specified map.</p>
-<h4>Usage:</h4>
-<pre><code>{cggm_add_dynpoint map=1 name=&#039;New York&#039; address=&#039;New York, NY&#039; icon=&#039;food&#039;}</code></pre><br/>
-<h4>Parameters:</h4>
-  <ul> 
-<li><strong>required</strong> - map : The (integer) ID of the map to add the point to</li>
-<li><strong>required</strong> - name : The name of the point to add</li>
-<li><em>optional</em> - desc/description : The HTML content to show in the info window</li>
-<li><em>optional</em> - address : The address of the location you are adding. (you must specify an address, or lat and long parameters)</li>
-<li><em>optional</em> - lat : The latitude of the location you are adding.</li>
-<li><em>optional</em> - long : The longitude of the location you are adding.</li>
-<li><em>optional</em> - category : A comma separated list of categories for this point (there is no need for the categories to already exists)</li>
-<li><em>optional</em> - tooltip : A tooltip to display when hovering over a point.</li>
-<li><em>optional</em> - icon : The name of an icon to use for this point.</li>
-  </ul>
-<br/>
-<p><strong>Note:</strong> Either the lat and long parameters must be specified, or the address.</p>
-<p><strong>Note:</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
-</ul>
-<h3>Upgrade Information:</h3>
-<p><strong>Note:</strong> For people upgrading from CGGoogleMaps 1.x to the new 2.x series some work may need to be done, particularly if you have changed your map template, or are using custom options.  You may need to revise the styling of your map templates, and then update/save the values in the map settings.</p>
-<p>Also: The sidebar_html, and sidebar_class parameters have been removed from the {cggm_add_dynpoint} smarty plugin.  This is due to the category functionality that has been added.</p>
-<h3>Support</h3>
-<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
-<ul>
-<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\&#039;s
-module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
-<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
-<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-<li>Lastly, you may have some success emailing the author directly.</li>  
-</ul>
-<h3>Requirements</h3>
-<p>This map functionality makes extensive use of <strong>JQuery</strong> it is your responsibility to include jquery in pages that use these maps and ensure that it is loaded before the map is called.  The easiest way to do this is by installing the JQueryTools module and adding {JQueryTools action=incjs} into the head portion of your page template.</p>
-<h3>Copyright and License</h3>
-<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p> ';
 $lang['height'] = 'Hoogte';
 $lang['help_anchor_location'] = '<strong>Opmerking:</strong> Anchor locaties specificeren de pixel locatie (in relatie tot de linkerboven hoek van de afbeelding) waar de pictogram moet komen als markeerpunt. Als er geen waarde is gegeven, wordt het midden van de pictogram gebruikt';
 $lang['help_icon_url'] = 'Benoem de URL van de ge&uuml;ploade PNG afbeelding.  Deze afbeelding mag niet groter zijn dan 32x32px, en moet transparant zijn. De URL moet vanuit de root van uw website worden benoemd';
@@ -210,7 +123,7 @@ $lang['longitude'] = 'Lengtegraad';
 $lang['make_default'] = 'Gebruik standaard dit pictogram';
 $lang['marker_categories'] = 'Marker Categorie&euml;n';
 $lang['marker_icons'] = 'Markeer Pictogram';
-$lang['marker_skipped'] = 'Geolocation (adres te kort/lang) mislukt.. marker &quot;%s&quot; is overgeslagen';
+$lang['marker_skipped'] = 'Geolocation (adres te kort/lang) mislukt. marker &quot;%s&quot; is overgeslagen';
 $lang['map'] = 'Kaart';
 $lang['maps'] = 'Kaarten';
 $lang['maptemplate_addedit'] = 'toevoegen/wijzigen map sjabloon';
@@ -230,7 +143,7 @@ $lang['msg_icons_reset'] = 'De pictogrammen zijn terug naar de standaard instell
 $lang['msg_icon_removed'] = 'Pictogram verwijderd van de database.  Er zijn geen bestanden verwijderd';
 $lang['msg_icon_updated'] = 'Pictogram informatie is gewijzigd';
 $lang['name'] = 'Naam';
-$lang['nav_control_opt'] = 'Navigatiebuttongrootte';
+$lang['nav_control_opt'] = 'Navigatiebutton Afmeting';
 $lang['none'] = 'Geen';
 $lang['panel'] = 'Paneel';
 $lang['points'] = 'Punten';
@@ -249,14 +162,14 @@ $lang['prompt_categories'] = 'Categorie&euml;n';
 $lang['prompt_directions'] = 'Bestemmingen';
 $lang['prompt_from_here'] = 'Vanaf hier';
 $lang['prompt_icon_selection'] = 'Pictogramselectie';
-$lang['prompt_info_window'] = 'Laat informatievenster zien';
+$lang['prompt_info_window'] = 'Toon informatievenster';
 $lang['prompt_info_trigger'] = 'Informatievenster Trigger';
 $lang['prompt_lookup_policy'] = 'Opzoekbeleid';
 $lang['prompt_lookup_service'] = 'Opzoekservice';
 $lang['prompt_to_here'] = 'Naar hier';
-$lang['prompt_sensor'] = 'Voeg geografischelocatie informatie toe aan de kaart';
+$lang['prompt_sensor'] = 'Voeg geografische locatie informatie toe aan de kaart';
 $lang['prompt_zoom'] = 'Zoomniveau';
-$lang['really_uninstall'] = 'Weet je zeker dat je deze module wilt verwijderen?';
+$lang['really_uninstall'] = 'Weet u zeker dat u deze module wilt verwijderen?';
 $lang['reset'] = 'Herstel';
 $lang['reset_icons'] = 'Reset pictogrammen';
 $lang['satellite'] = 'Sateliet';
@@ -275,6 +188,7 @@ $lang['tab_jstemplate'] = 'Javascript sjabloon';
 $lang['tab_settings'] = 'Instellingen';
 $lang['tab_maptemplate'] = 'Map Sjabloon';
 $lang['text'] = 'Tekst';
+$lang['title_combined_marker'] = 'Meerdere resultaten voor deze lokatie';
 $lang['to'] = 'Naar';
 $lang['type'] = 'Soort';
 $lang['type_controls'] = 'Geef typebesturingsknoppen weer';
@@ -285,9 +199,8 @@ $lang['use_marker_icon'] = 'Kies een markeerpictogram';
 $lang['width'] = 'Breedte';
 $lang['window'] = 'Venster';
 $lang['zoom_encompass'] = 'Inzoom omgeving';
-$lang['utmz'] = '156861353.1327535062.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utma'] = '156861353.1501314252.1327535062.1327535062.1327535062.1';
-$lang['qca'] = 'P0-802263609-1268423862699';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.1421760662.1339440540.1339440540.1339440540.1';
+$lang['utmz'] = '156861353.1339440540.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
