@@ -246,24 +246,25 @@ class cggm_map_generator
 
   protected function generate_header()
   {
-    // todo, implement map header template
-    $defertxt='';
-    if( $this->_defer ) $defertxt = ' defer="defer"';
-    $url = 'http://maps.google.com/maps/api/js';
+    static $header_generated;
+    if( $header_generated == 0 ) {
+      $header_generated = 1;
+      $defertxt='';
+      if( $this->_defer ) $defertxt = ' defer="defer"';
+      $url = 'http://maps.google.com/maps/api/js';
 
-    $args = array();
-
-    $sensor = 'false';
-    if( $this->_map->sensor )
-      {
+      $args = array();
+      $sensor = 'false';
+      if( $this->_map->sensor ) {
 	$sensor = 'true';
       }
-    $args['sensor'] = $sensor;
+      $args['sensor'] = $sensor;
 
-    $url .= '?' . cge_array::implode_with_key($args);
+      $url .= '?' . cge_array::implode_with_key($args);
 
-    $tpl = '<script src="%s" type="text/javascript" charset="utf-8"%s></script>';
-    return sprintf($tpl,$url,$defertxt);
+      $tpl = '<script src="%s" type="text/javascript" charset="utf-8"%s></script>';
+      return sprintf($tpl,$url,$defertxt);
+    }
   }
 
 
@@ -442,10 +443,7 @@ class cggm_map_generator
     $smarty->assign('generator',$this);
 
     $output = $this->generate_header();
-    if( $output )
-      {
-	$smarty->assign('map_header',$output);
-      }
+    $smarty->assign('map_header',$output);
 
     // parse through the markers, cleaning up icons if necessary.
     $this->prepare_markers();
@@ -465,15 +463,13 @@ class cggm_map_generator
 	  }
       }
 
-    if( count($this->_markers) )
-      {
-	// add the marker data to the dom.
-	$output = $this->generate_marker_html();
-	if( $output )
-	  {
-	    $smarty->assign('map_marker_data',$output);
-	  }
+    if( count($this->_markers) ) {
+      // add the marker data to the dom.
+      $output = $this->generate_marker_html();
+      if( $output ) {
+	$smarty->assign('map_marker_data',$output);
       }
+    }
 
     if( count($this->_markers) && $map->sidebar )
       {
